InterruptKind

Enum InterruptKind 

pub enum InterruptKind {
    Level,
    Edge,
}
Available on crate feature unstable only.
Interrupt kind

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Level

Level interrupt



Edge

Edge interrupt