Priority

Enum Priority 

#[repr(u8)]
pub enum Priority {
Show 15 variants Priority1 = 1, Priority2 = 2, Priority3 = 3, Priority4 = 4, Priority5 = 5, Priority6 = 6, Priority7 = 7, Priority8 = 8, Priority9 = 9, Priority10 = 10, Priority11 = 11, Priority12 = 12, Priority13 = 13, Priority14 = 14, Priority15 = 15,
}
Interrupt priority levels.

A higher numeric value means higher priority. Interrupt requests at higher priority levels will be able to preempt code running at a lower RunLevel.

Variants



Priority1 = 1

Priority level 1.



Priority2 = 2

Priority level 2.



Priority3 = 3

Priority level 3.



Priority4 = 4

Priority level 4.



Priority5 = 5

Priority level 5.



Priority6 = 6

Priority level 6.



Priority7 = 7

Priority level 7.



Priority8 = 8

Priority level 8.



Priority9 = 9

Priority level 9.



Priority10 = 10

Priority level 10.



Priority11 = 11

Priority level 11.



Priority12 = 12

Priority level 12.



Priority13 = 13

Priority level 13.



Priority14 = 14

Priority level 14.



Priority15 = 15

Priority level 15.

Implementations

Source

impl Priority

pub const fn max() -> Priority

Available on crate feature unstable only.

Maximum interrupt priority

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub const fn min() -> Priority

Minimum interrupt priority