RunLevel

Enum RunLevel 

#[non_exhaustive]
pub enum RunLevel { ThreadMode, Interrupt(ElevatedRunLevel), }
Represents the priority level of running code.

Interrupts at or below this level are masked.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ThreadMode

Thread mode.

This is the lowest level. No interrupts are masked by the run level.



Interrupt(ElevatedRunLevel)

An elevated level, usually an interrupt handler’s.

Implementations

Source

impl RunLevel

pub fn current() -> Self

Returns the current run level.

Examples
use esp_hal::interrupt::RunLevel;

let level = RunLevel::current();
println!("Current run level: {:?}", level);
pub unsafe fn change(to: Self) -> Self

Available on crate feature unstable only.

Changes the current run level to the specified level and returns the previous level.

Safety

This function must only be used to raise the run level and to restore it to a previous value. It must not be used to arbitrarily lower the run level.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn is_thread(&self) -> bool

Checks if the run level indicates thread mode.

This function can be used to determine if the CPU is executing an interrupt handler.

Examples
use esp_hal::interrupt::RunLevel;

let level = RunLevel::current();

if level.is_thread() {
    println!("Running in thread mode");
} else {
    println!("Running in an interrupt handler");
}