bound_handler

Function bound_handler 

pub fn bound_handler(interrupt: Interrupt) -> Option<IsrCallback>
Available on crate feature unstable only.
Returns the currently bound interrupt handler.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.