enable

Function enable 

pub fn enable(interrupt: Interrupt, level: Priority)
Available on crate feature unstable only.
Enables a peripheral interrupt at a given priority, using vectored CPU interrupts.

Note that interrupts still need to be enabled globally for interrupts to be serviced.

Internally, this function maps the interrupt to the appropriate CPU interrupt for the specified priority level.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.