IsrCallback

Struct IsrCallback 

pub struct IsrCallback { /* private fields */ }
Available on crate feature unstable only.
Represents an ISR callback function

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl IsrCallback

pub fn new(f: extern "C" fn()) -> Self

Construct a new callback from the callback function.

pub fn address(self) -> usize

Returns the address of the callback.

pub fn callback(self) -> extern "C" fn()

The callback function.

This is aligned and can be called.