ElevatedRunLevel

Enum ElevatedRunLevel 

#[repr(u8)]
pub enum ElevatedRunLevel {
Show 15 variants Level1 = 1, Level2 = 2, Level3 = 3, Level4 = 4, Level5 = 5, Level6 = 6, Level7 = 7, Level8 = 8, Level9 = 9, Level10 = 10, Level11 = 11, Level12 = 12, Level13 = 13, Level14 = 14, Level15 = 15,
}
Interrupt run levels.

Variants



Level1 = 1

Run level 1.



Level2 = 2

Run level 2.



Level3 = 3

Run level 3.



Level4 = 4

Run level 4.



Level5 = 5

Run level 5.



Level6 = 6

Run level 6.



Level7 = 7

Run level 7.



Level8 = 8

Run level 8.



Level9 = 9

Run level 9.



Level10 = 10

Run level 10.



Level11 = 11

Run level 11.



Level12 = 12

Run level 12.



Level13 = 13

Run level 13.



Level14 = 14

Run level 14.



Level15 = 15

Run level 15.

Implementations

Source

impl ElevatedRunLevel

pub const fn from_priority(priority: Priority) -> Self

Converts a Priority into an ElevatedRunLevel.

Source

impl ElevatedRunLevel

pub const fn max() -> ElevatedRunLevel

Available on crate feature unstable only.

Returns the highest run level

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub const fn min() -> ElevatedRunLevel

Minimum elevated run level