pub fn bind_handler(interrupt: Interrupt, handler: InterruptHandler)Available on crate feature
unstable only.Expand description
Binds the given handler to a peripheral interrupt.
The interrupt handler will be enabled at the specified priority level.
The interrupt handler will be called on the core where it is registered. Only one interrupt handler can be bound to a peripheral interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.