pub fn disable(core: Cpu, interrupt: Interrupt)Available on crate feature
unstable only.Expand description
Disable the given peripheral interrupt.
Internally, this function maps the interrupt to a disabled CPU interrupt.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.