pub struct IsrCallback { /* private fields */ }Available on crate feature
unstable only.Expand description
Represents an ISR callback function
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations